// You can import API functions like this from D3.js.
import { select, selectAll } from 'd3';

// You can import local ES6 modules like this. See message.js!

const vizData = [
  {
    src: 'https://vizhub.com/IeKimI/6ab4774a0c784f66a3d4c90ea8d5e9a6?mode=full',
    caption: 'Artworks by Artist'
  },
  {
    src: 'https://vizhub.com/IeKimI/e4286b8b782648de9f4871dc7bdb7212?mode=full',
    caption: 'Artist Nationality'
  },
  {
    src: 'https://vizhub.com/IeKimI/d53fd658b3614a9ca281cd3153701018?mode=full',
    caption: 'Medium'
  },
  {
    src: 'https://vizhub.com/IeKimI/19352f8c88a1407ba2ec27940469a1a2?mode=full',
    caption: 'Department & Classification'
  }
];

const container = d3.select('#viz-container');

const viz = container.selectAll('.viz')
  .data(vizData)
  .enter()
  .append('div')
  .attr('class', 'viz')
  .html(function(d) {
    return `
      <iframe src="${d.src}" width="300" height="150"></iframe>
      <div class="caption">${d.caption}</div>
    `;
  });

// Select all visualizations
const visualizations = d3.selectAll('.viz');
// Set maximum width and height for enlarged iframe
const MAX_WIDTH = window.innerWidth - 100;
const MAX_HEIGHT = window.innerHeight - 100;

// Define function to toggle full screen view
function toggleFullScreen() {
  const viz = d3.select(event.currentTarget);
  const iframe = viz.select('iframe');
  const isEnlarged = viz.classed('viz-enlarged');

  // If not enlarged, enlarge the clicked image and shrink the others
  if (!isEnlarged) {
    // Enlarge clicked image
    iframe.attr('width', MAX_WIDTH);
    iframe.attr('height', MAX_HEIGHT);
    viz.style('opacity', 1);

    // Shrink other images
    const otherViz = visualizations.filter((d, i) => i !== viz.nodes()[0].dataset.index);
    otherViz.classed('viz-shrunk', true);
    // otherViz.style('opacity', 0.5);
  } else {
    // Shrink clicked image and restore others
    iframe.attr('width', 300);
    iframe.attr('height', 150);
    // viz.style('opacity', 0.5);
    visualizations.classed('viz-shrunk', false);
    visualizations.style('opacity', 1);
  }

  // Toggle enlarged class
  viz.classed('viz-enlarged', !isEnlarged);

  // Add back-to-home button if enlarged
  if (!isEnlarged) {
    viz.append('button')
      .text('Back to Home')
      .on('click', toggleFullScreen);
  } else {
    viz.select('button').remove();
  }
}

// Add click event listener to each visualization
visualizations.on('click', toggleFullScreen);
